==> nextcloud-21.0.4.tgz: nextcloud/apps/weather_status/l10n/ko.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "알 수 없는 주소",
    "No result." : "결과 없음.",
    "Malformed JSON data." : "잘못 구성된 JSON 데이터.",
    "Error" : "오류",
    "Weather status" : "날씨 현황",
    "Weather status in your dashboard" : "내 대시보드에 있는 날씨 현황",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "날씨 현황이 대시보드 앱에 통합되었습니다.\n사용자의 현재 위치를 자동 혹은 수동으로 지정할 수 있습니다. 그 후 6시간의 일기예보가 표시됩니다.\n날씨 현황은 달력 앱과 같이 다른 곳에서도 통합될 수 있습니다.",
    "Detect location" : "위치 감지",
    "Set custom address" : "주소 설정",
    "Favorites" : "즐겨찾기",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit}, {time}에 맑음",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit}, {time}에 구름",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit}, {time}에 구름 조금",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit}, {time}에 안개",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit}, {time}에 약한 비",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit}, {time}에 비",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit}, {time}에 거센 비",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit}, {time}에 소나기",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit}, {time}에 약한 소나기",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit}, {time}에 거센 소나기",
    "More weather for {adr}" : "{adr} 날씨 더 보기",
    "Loading weather" : "날씨 불러오는 중",
    "Set location for weather" : "날씨 위치 설정",
    "Remove from favorites" : "즐겨찾기에서 제거",
    "Add as favorite" : "즐겨찾기로 추가",
    "You are not logged in." : "당신은 로그인하지 않았습니다.",
    "There was an error getting the weather status information." : "날씨 현황 정보를 불러오는 동안 오류가 발생했습니다.",
    "No weather information found" : "날씨 정보 없음",
    "Location not found" : "위치를 찾을 수 없습니다",
    "There was an error setting the location address." : "이 위치의 주소를 설정하는 동안 오류가 발생했습니다.",
    "There was an error setting the location." : "주소를 설정하는 동안 오류가 발생했습니다.",
    "There was an error using personal address." : "개인 주소를 사용하는 동안 오류가 발생했습니다.",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "날씨 현황이 대시보드 앱에 통합되었습니다.\n사용자의 현재 위치를 자동 혹은 수동으로 지정할 수 있습니다. 그 후 6시간의 일기예보가 표시됩니다.\n날씨 현황은 달력 앱과 같이 다른 곳에서도 통합될 수 있습니다."
},
"nplurals=1; plural=0;");

==> nextcloud-21.0.8p0.tgz: nextcloud/apps/weather_status/l10n/ko.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "알 수 없는 주소",
    "No result." : "결과 없음.",
    "Malformed JSON data." : "잘못 구성된 JSON 데이터.",
    "Error" : "오류",
    "Weather status" : "날씨 현황",
    "Weather status in your dashboard" : "내 대시보드에 있는 날씨 현황",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "날씨 현황이 대시보드 앱에 통합되었습니다.\n사용자의 현재 위치를 자동 혹은 수동으로 지정할 수 있습니다. 그 후 6시간의 일기예보가 표시됩니다.\n날씨 현황은 달력 앱과 같이 다른 곳에서도 통합될 수 있습니다.",
    "Detect location" : "위치 감지",
    "Set custom address" : "주소 설정",
    "Favorites" : "즐겨찾기",
    "More weather for {adr}" : "{adr} 날씨 더 보기",
    "Loading weather" : "날씨 불러오는 중",
    "Remove from favorites" : "즐겨찾기에서 제거",
    "Add as favorite" : "즐겨찾기로 추가",
    "You are not logged in." : "당신은 로그인하지 않았습니다.",
    "There was an error getting the weather status information." : "날씨 현황 정보를 불러오는 동안 오류가 발생했습니다.",
    "No weather information found" : "날씨 정보 없음",
    "Location not found" : "위치를 찾을 수 없습니다",
    "There was an error setting the location address." : "이 위치의 주소를 설정하는 동안 오류가 발생했습니다.",
    "There was an error setting the location." : "주소를 설정하는 동안 오류가 발생했습니다.",
    "There was an error saving the mode." : "모드 저장에 오류가 있습니다.",
    "There was an error using personal address." : "개인 주소를 사용하는 동안 오류가 발생했습니다.",
    "Set location for weather" : "날씨 위치 설정",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "날씨 현황이 대시보드 앱에 통합되었습니다.\n사용자의 현재 위치를 자동 혹은 수동으로 지정할 수 있습니다. 그 후 6시간의 일기예보가 표시됩니다.\n날씨 현황은 달력 앱과 같이 다른 곳에서도 통합될 수 있습니다.",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit}, {time}에 맑음",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit}, {time}에 구름",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit}, 낮 {time}시에 맑음",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit}, 밤 {time}시에 맑음",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit}, {time}에 구름 조금",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit}, {time}에 안개",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit}, {time}에 약한 비",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit}, {time}에 비",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit}, {time}에 거센 비",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit}, {time}에 소나기",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit}, {time}에 약한 소나기",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit}, {time}에 거센 소나기"
},
"nplurals=1; plural=0;");
